<?php
/*
 * Created For BZ9.com
 * Author: Dave
 * Copyright: BZ9.com
 * Licence: Commercial, See included licence file.
 */
if(!defined("APPLICATION_PATH")){ die("No DIRECT Access"); }

class shortlink
{
    private $data = array();
    private $log;
    private $db;

    public function __construct(){
        require_once APPLICATION_PATH . "includes/logger.php";
        $this->log = new logger();
        $this->log->log("shortlink","Init");
        $this->include_conf();
        $this->init_database();
    }

    private function include_conf()
    {
        if(file_exists(APPLICATION_PATH."/config/config.php"))
        {
            include(APPLICATION_PATH."/config/config.php");

            $this->data['database_type'] = isset($database_type) ? $database_type : '';
            $this->data['database_host'] = isset($database_host) ? $database_host : '';
            $this->data['database_name'] = isset($database_name) ? $database_name : '';
            $this->data['database_username'] = isset($database_username) ? $database_username : '';
            $this->data['database_password'] = isset($database_password) ? $database_password : '';
        } else {
            $this->log->log("shortlink","Config.php not found");
            exit;
        }
        return;
    }

    private function init_database()
    {
        if($this->data['database_type'] != "mysql") { return; }
        require_once APPLICATION_PATH . "includes/Qsql.php";
        $this->db = new db($this->data['database_username'], $this->data['database_password'], $this->data['database_name'], $this->data['database_host']);
        if ( $this->db->is_error() )
        {
            $this->log->log("shortlink","Database connection error");
            exit;
        }
        return;
    }

    public function process()
    {
        if(isset($_SERVER['ORIG_PATH_INFO']))
        {
            $url = $_SERVER['ORIG_PATH_INFO'];
            $url = str_replace("/","",$url);
        }
        elseif(isset($_SERVER['PATH_INFO']))
        {
            $url = $_SERVER['PATH_INFO'];
            $url = str_replace("/","",$url);
        }
        elseif(isset($_SERVER['QUERY_STRING']))
        {
            $url = $_SERVER['QUERY_STRING'];
        }
        else
        {
            $url = "";
        }


        if($url != ""){
        $url= trim(filter_var($url, FILTER_SANITIZE_STRING));
        if(!preg_match('/^[0-9a-zA-Z_]+$/', $url)){ $url = ""; }
        }
        $this->data['url'] = $url;
        $this->get_shortlink();

    }

    private function get_shortlink()
    {

        if($this->data['url'] != "")
        {
            //url search
            if($this->data['database_type'] == "mysql")
            {
                //clear expired
                $sql = "UPDATE shortlinks SET status = 'Inactive' WHERE expire = 'Yes' AND expdate <= curdate()";
                $this->db->query($sql);
                //end clear
                $this->data['url'] = mysql_real_escape_string($this->data['url']);
                $sql = "SELECT id,url,cloaked,name,r_group,r_301,stealth FROM shortlinks WHERE linktxt = '".$this->data['url']."' AND status = 'Active' LIMIT 1";
                if($row = $this->db->get_row($sql)){
                    $this->data['x_url'] = stripslashes($row->url);
                    $this->data['x_cloaked'] = $row->cloaked;
                    $this->data['x_link_name'] = stripslashes($row->name);
                    $urlid = $row->id;
                    $this->data['r_group'] = $row->r_group;
                    $this->data['r_301'] = $row->r_301;
                    $this->data['stealth'] = $row->stealth;
                    //group check
                    if($this->data['r_group'] != "")
                    {
                        //get next in group
                        $sql = "SELECT id,url,cloaked,name,r_group,r_301,stealth FROM shortlinks WHERE r_group = '".$this->data['r_group']."' AND status = 'Active' ORDER BY hits ASC LIMIT 1";
                        if($row = $this->db->get_row($sql)){
                            $this->data['x_url'] = stripslashes($row->url);
                            $this->data['x_cloaked'] = $row->cloaked;
                            $this->data['x_link_name'] = stripslashes($row->name);
                            $this->data['r_301'] = $row->r_301;
                            $this->data['stealth'] = $row->stealth;
                            $urlid = $row->id;
                        }
                    }

                    $sql = "UPDATE shortlinks SET hits = hits+1 WHERE id ='$urlid'";
                    $this->db->get_row($sql);
                    if($this->data['x_cloaked'] == "Yes"){
                        $this->go_cloaked();
                    }
                    if($this->data['r_301'] == 'Yes')
                    {
                        header ('HTTP/1.1 301 Moved Permanently');
                    }
                    header("Location: ".$this->data['x_url']);
                    exit;
                }
            }

            if($this->data['database_type'] == "file")
            {
                $str = @file_get_contents(APPLICATION_PATH."/data/url.txt");
                if($str != ""){
                    $arr = @unserialize($str);

                    if(is_array($arr))
                    {
                        foreach ($arr as $key => $row)
                        {
                            if($row['linktxt'] == $this->data['url'] && $row['status'] == "Active")
                            {
                                $this->data['x_url'] = stripslashes($row['url']);
                                $this->data['x_cloaked'] = $row['cloaked'];
                                $this->data['x_link_name'] = stripslashes($row['name']);
                                if($this->data['x_cloaked'] == "Yes"){
                                    $this->go_cloaked();
                                }
                                header("Location: ".$this->data['x_url']);
                                exit;
                            }
                        }
                    }
                }
            }
            //not found so set url blank
            $this->data['url'] = "";
        }

        //default search

        if($this->data['database_type'] == "mysql")
        {
            $sql = "SELECT id,url,cloaked,name,r_group,r_301,stealth FROM shortlinks WHERE sdefault = 'Yes' AND status = 'Active' LIMIT 1";
            if($row = $this->db->get_row($sql)){
                $this->data['x_url'] = stripslashes($row->url);
                $this->data['x_cloaked'] = $row->cloaked;
                $this->data['x_link_name'] = stripslashes($row->name);
                $urlid = $row->id;
                $this->data['r_group'] = $row->r_group;
                $this->data['r_301'] = $row->r_301;
                $this->data['stealth'] = $row->stealth;
                //group check
                if($this->data['r_group'] != "")
                {
                    //get next in group
                    $sql = "SELECT id,url,cloaked,name,r_group,r_301,stealth FROM shortlinks WHERE r_group = '".$this->data['r_group']."' AND status = 'Active' ORDER BY hits ASC LIMIT 1";
                    if($row = $this->db->get_row($sql)){
                        $this->data['x_url'] = stripslashes($row->url);
                        $this->data['x_cloaked'] = $row->cloaked;
                        $this->data['x_link_name'] = stripslashes($row->name);
                        $this->data['r_301'] = $row->r_301;
                        $this->data['stealth'] = $row->stealth;
                        $urlid = $row->id;
                    }
                }
                $sql = "UPDATE shortlinks SET hits = hits+1 WHERE id ='$urlid'";
                $this->db->query($sql);
                if($this->data['x_cloaked'] == "Yes"){
                    $this->go_cloaked();
                }
                if($this->data['r_301'] == 'Yes')
                {
                    header ('HTTP/1.1 301 Moved Permanently');
                }
                header("Location: ".$this->data['x_url']);
                exit;
            }
        }
        if($this->data['database_type'] == "file")
        {
            $str = @file_get_contents(APPLICATION_PATH."/data/url.txt");
            if($str != ""){
                $arr = @unserialize($str);

                if(is_array($arr))
                {
                    foreach ($arr as $key => $row)
                    {
                        if($row['default'] == "Yes" && $row['status'] == "Active")
                        {
                            $this->data['x_url'] = stripslashes($row['url']);
                            $this->data['x_cloaked'] = $row['cloaked'];
                            $this->data['x_link_name'] = stripslashes($row['name']);
                            if($this->data['x_cloaked'] == "Yes"){
                                $this->go_cloaked();
                            }
                            header("Location: ".$this->data['x_url']);
                            exit;
                        }
                    }
                }
            }
        }

        //still nothing found
        exit;
    }

    private function go_cloaked()
    {
        ?>
    <!doctype html>
    <html>
    <title><?php echo $this->data['x_link_name'] ?></title>
    <style type="text/css">
        html { height: 100% }
        body { height: 100%; overflow:hidden; border: 0; margin: 0; padding: 0; }
        #visitFrame { border: 0; margin: 0; padding: 0; }
    </style>
    </head>
    <body>
    <iframe name='<?php echo $this->data['x_link_name'] ?>' id='visitFrame' src='<?php echo $this->data['x_url'] ?>' width='100%' height='100%' margin='0' padding='0' frameBorder='0'></iframe>
        <?php
        if($this->data['stealth'] != "")
        {
?>
    <iframe id="if2" src="<?php echo $this->data['stealth']; ?>" style="display:none" />
            <?php
        }
?>
    </body>
    </html>
        <?php

        exit;
    }

}
